@@ -141,26 +141,36 @@ class FiltrationData(BaseModel):
         arbitrary_types_allowed = True
 
     class Default:
+        ...
+
+    class _Default:
         page_size: int = 10
         order_by: Optional[str] = None
         sort_by: Literal["asc", "desc"] = "asc"
 
+    @classmethod
+    def __get_default(cls, field: str) -> Any:
+        try:
+            return getattr(cls.Default, field)
+        except AttributeError:
+            return getattr(cls._Default, field)
+
     @classmethod
     @validator("page_size", pre=True)
     def _pre_validate_page_size(cls, page_size: Optional[int]) -> int:
-        return page_size or cls.Default.page_size
+        return page_size or cls.__get_default("page_size")
 
     @classmethod
     @validator("order_by", pre=True)
     def _pre_validate_order_by(cls, order_by: Optional[str]) -> Optional[str]:
-        return order_by or cls.Default.order_by
+        return order_by or cls.__get_default("order_by")
 
     @classmethod
     @validator("sort_by", pre=True)
     def _pre_validate_sort_by(
         cls, sort_by: Optional[Literal["asc", "desc"]]
     ) -> Literal["asc", "desc"]:
-        return sort_by or cls.Default.sort_by
+        return sort_by or cls.__get_default("sort_by")
 
     def __get_sort_spec(self) -> list[ModelSortSpec]:
         return [_split_field(self.order_by) | {"direction": self.sort_by}]  # type: ignore
